# ou-book-theme

[![PyPI - Version](https://img.shields.io/pypi/v/ou-book-theme.svg)](https://pypi.org/project/ou-book-theme)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ou-book-theme.svg)](https://pypi.org/project/ou-book-theme)

-----

**Table of Contents**

- [Installation](#installation)

## Installation

```console
pip install ou-book-theme
```
